/* 
 * (c) Copyright IBM Corp. 2005 2006. All Rights Reserved. 
 * Licensed Materials - Use restricted, please refer to the "Samples Gallery" terms and conditions in the IBM International Program License Agreement. 
 */
package importer;

import java.io.File;

import org.eclipse.jface.dialogs.IDialogPage;
import org.eclipse.jface.wizard.IWizardPage;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Dialog;
import org.eclipse.swt.widgets.DirectoryDialog;
import org.eclipse.swt.widgets.FileDialog;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Text;

import com.ibm.rational.test.mt.importer.interfaces.IMTAImportSourceConfigSettings;
import com.ibm.rational.test.mt.importer.interfaces.MTANodeKnownProperties;

/**
 *
 * This class creates the import configuration page for the import example.
 */
public class ExampleConfigPage implements ModifyListener
{
	/**
	 * Wizard Page where the controls created by this instance will be displayed.
	 */
	private IWizardPage page;
	/** 
	 * A container which will display the configuration information.
	 */
	private Composite container;
	
	private Text sourceFileText;
	private String sourceFile;
	
	private Text destFolerText;
	private String destFolder;
	
	/**
	 * @see IDialogPage#createControl(Composite)
	 */
	public void createControl( Composite parent ) 
	{
		container = new Composite( parent, SWT.NULL );

		// Add controls to the composite.
		GridLayout gridLayout = new GridLayout( );
		gridLayout.numColumns = 3;
		container.setLayout( gridLayout );
		GridData gd = new GridData( GridData.FILL_HORIZONTAL | GridData.END );
		container.setLayoutData( gd );
		
		sourceFileText = createFileSelectionControls(container, "&Source File:", true);
		destFolerText = createFileSelectionControls(container, "&Output Folder:", false);
		 
		updateStatus( );
	}

	private Text createFileSelectionControls(final Composite parent, String label, final boolean isFile) {
		// Label
		Label lblImportFile = new Label( parent, SWT.NONE );
		lblImportFile.setText( label );
		lblImportFile.setLayoutData( new GridData( GridData.BEGINNING ));

		// Text entry field
		final Text textField = new Text( parent, SWT.BORDER );
		GridData data = new GridData( GridData.FILL_HORIZONTAL );
		textField.setLayoutData( data );
		textField.addModifyListener( this );
		
		// Browse button
		Button btnBrowse = new Button( parent, SWT.PUSH );
		btnBrowse.setText( "&Browse..." );
		data = new GridData( GridData.END );
		btnBrowse.setLayoutData( data );
		btnBrowse.addSelectionListener( new SelectionAdapter( ) {
		 	public void widgetSelected( SelectionEvent e )
		 	{
		 		Dialog dlg = null;
		 		String fileName = null;
		 		if(isFile)
		 		{
		 			dlg = new FileDialog(parent.getShell());
		 			fileName = ((FileDialog)dlg).open();
		 		}
		 		else
		 		{
		 			dlg = new DirectoryDialog( parent.getShell( ) );
		 			fileName = ((DirectoryDialog)dlg).open();
		 		}
				if ( fileName != null && !fileName.equals("") )
				{
					textField.setText( fileName );
					updateStatus();
				}
		 	}
		 });
		
		return textField;
	}
	
	/**
	 * Gets the control which has other controls as children
	 * @return
	 */
	protected Control getControl( )
	{
		return container;
	}
	
	/**
	 * Sets the wizard page
	 * @param page
	 */
	protected void setWizardPage( IWizardPage page )
	{
		this.page = page;
		//MESSAGE excel.config.page.title=Configuration Page
		page.setTitle( "Example Configuration Page" );
	}
	
	/**
	 * Adds key value pairs to ConfigSettings object.  This information
	 * will be passed to the implementor.
	 * @param cfgSettings
	 */
	protected void addConfigProperties( IMTAImportSourceConfigSettings cfgSettings )
	{
		String fileName = sourceFileText.getText();
		cfgSettings.setProperty( MTANodeKnownProperties.PROPERTY_FILESOURCE, fileName );
	}
	
	public String getOutputFolder()
	{
		return destFolder;
	}
	
	/**
	 * Updates the page description and button states.
	 * @param msg
	 */
	private void updateStatus( )
	{
		WizardPage wizardPage = (WizardPage) page;
		
		String status = updateStatus(sourceFile);
		if(status == null)
			status = updateStatus(destFolder);
		
		wizardPage.setErrorMessage(status);
		wizardPage.setPageComplete(status == null);
	}
	
	private String updateStatus(String file)
	{
		if ( file != null && file.length() > 0 )
		{
			if ( !new File(file).exists() )
				return (file + " does not exist");
		}
		else
			return "Enter a value for source file or output folder.";
		
		return null;
	}
	
	public void modifyText(ModifyEvent e) {
		if(e.widget == sourceFileText)
			sourceFile = sourceFileText.getText();
		else if(e.widget == destFolerText)
			destFolder = destFolerText.getText();
		
		updateStatus();
	}
}
